@@ -1,8 +1,7 @@
 package App::SimpleScan::Plugin::Tester;
 
 sub options {
-  # Test that the option handler unpacks this correctly.
-  ['tester', \$tester];
+  return('tester', \$tester);
 }
 
 sub pragmas {
@@ -16,4 +15,5 @@ sub test_modules {
 sub per_test_code {
   return (qq(diag "test code inserted"));
 }
+
 1;
